aboutsummaryrefslogtreecommitdiffstats
path: root/keystone-moon/keystone/credential/core.py
diff options
context:
space:
mode:
Diffstat (limited to 'keystone-moon/keystone/credential/core.py')
-rw-r--r--keystone-moon/keystone/credential/core.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/keystone-moon/keystone/credential/core.py b/keystone-moon/keystone/credential/core.py
index d3354ea3..2368439e 100644
--- a/keystone-moon/keystone/credential/core.py
+++ b/keystone-moon/keystone/credential/core.py
@@ -12,7 +12,7 @@
# License for the specific language governing permissions and limitations
# under the License.
"""Main entry point into the Credentials service."""
import abc
@@ -40,6 +40,8 @@ class Manager(manager.Manager):
"""
+ driver_namespace = 'keystone.credential'
+
def __init__(self):
super(Manager, self).__init__(CONF.credential.driver)
@@ -12,7 +12,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-"""Main entry point into the Credentials service."""
+"""Main entry point into the Credential service."""
import abc